Kill unused error code WRITE_OK.
[paraslash.git] / sched.c
diff --git a/sched.c b/sched.c
index e122903e8e46823ed2a4b987cf3264782ca3040e..42c5f14215df5e3f28ff91c11469b5dacf9f2e4a 100644 (file)
--- a/sched.c
+++ b/sched.c
@@ -1,24 +1,15 @@
 /*
- * Copyright (C) 2006 Andre Noll <maan@systemlinux.org>
+ * Copyright (C) 2006-2008 Andre Noll <maan@systemlinux.org>
  *
- *     This program is free software; you can redistribute it and/or modify
- *     it under the terms of the GNU General Public License as published by
- *     the Free Software Foundation; either version 2 of the License, or
- *     (at your option) any later version.
- *
- *     This program is distributed in the hope that it will be useful,
- *     but WITHOUT ANY WARRANTY; without even the implied warranty of
- *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *     GNU General Public License for more details.
- *
- *     You should have received a copy of the GNU General Public License
- *     along with this program; if not, write to the Free Software
- *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+ * Licensed under the GPL v2. For licencing details see COPYING.
  */
 
 /** \file sched.c paraslash's scheduling functions */
 
+#include <dirent.h> /* readdir() */
+#include <assert.h>
 #include <sys/time.h>
+
 #include "para.h"
 #include "ipc.h"
 #include "fd.h"
@@ -65,7 +56,9 @@ static void sched_post_select(struct sched *s)
 /**
  * the core function for all paraslash programs
  *
- * Short and sweet. It updates the global \a now pointer, calls all registered
+ * \param s pointer to the scheduler struct
+ *
+ * This function updates the global \a now pointer, calls all registered
  * pre_select hooks which may set the timeout and add any file descriptors to
  * the fd sets of \a s.  Next, it calls para_select() and makes the result available
  * to the registered tasks by calling their post_select hook.
@@ -75,7 +68,7 @@ static void sched_post_select(struct sched *s)
  *
  * \sa task, now.
  */
-int sched(struct sched *s)
+int schedule(struct sched *s)
 {
        if (!initialized)
                return -E_NOT_INITIALIZED;
@@ -155,7 +148,7 @@ void unregister_task(struct task *t)
 /**
  * unregister all tasks
  *
* This will cause \a sched() to return immediately because both the
  * \a pre_select_list and the \a post_select_list are empty.
  */
 void sched_shutdown(void)
@@ -155,7 +148,7 @@ void unregister_task(struct task *t)
  * unregister all tasks
  *
- * This will cause \a sched() to return immediately because both the
+ * This will cause \a schedule() to return immediately because both the
  * \a pre_select_list and the \a post_select_list are empty.
  */